==> quench-vue-0.4.0.tgz: package/umd/quench-vue.js <==
/*!
 * quench-vue v0.4.0 - http://mattstow.com
 * MIT Licensed
 */
(function webpackUniversalModuleDefinition(root, factory) {
	if(typeof exports === 'object' && typeof module === 'object')
		module.exports = factory();
	else if(typeof define === 'function' && define.amd)
		define([], factory);
	else if(typeof exports === 'object')
		exports["quenchVue"] = factory();
	else
		root["quenchVue"] = factory();
})(this, function() {
return /******/ (function(modules) { // webpackBootstrap
/******/ 	// The module cache
/******/ 	var installedModules = {};
/******/
/******/ 	// The require function
/******/ 	function __webpack_require__(moduleId) {
/******/
/******/ 		// Check if module is in cache
/******/ 		if(installedModules[moduleId]) {
/******/ 			return installedModules[moduleId].exports;
/******/ 		}
/******/ 		// Create a new module (and put it into the cache)
/******/ 		var module = installedModules[moduleId] = {
/******/ 			i: moduleId,
/******/ 			l: false,
/******/ 			exports: {}
/******/ 		};
/******/
/******/ 		// Execute the module function
/******/ 		modules[moduleId].call(module.exports, module, module.exports, __webpack_require__);
/******/
/******/ 		// Flag the module as loaded
/******/ 		module.l = true;
/******/
/******/ 		// Return the exports of the module
/******/ 		return module.exports;
/******/ 	}
/******/
/******/
/******/ 	// expose the modules object (__webpack_modules__)
/******/ 	__webpack_require__.m = modules;
/******/
/******/ 	// expose the module cache
/******/ 	__webpack_require__.c = installedModules;
/******/
/******/ 	// define getter function for harmony exports
/******/ 	__webpack_require__.d = function(exports, name, getter) {
/******/ 		if(!__webpack_require__.o(exports, name)) {
/******/ 			Object.defineProperty(exports, name, {
/******/ 				configurable: false,
/******/ 				enumerable: true,
/******/ 				get: getter
/******/ 			});
/******/ 		}
/******/ 	};
/******/
/******/ 	// getDefaultExport function for compatibility with non-harmony modules
/******/ 	__webpack_require__.n = function(module) {
/******/ 		var getter = module && module.__esModule ?
/******/ 			function getDefault() { return module['default']; } :
/******/ 			function getModuleExports() { return module; };
/******/ 		__webpack_require__.d(getter, 'a', getter);
/******/ 		return getter;
/******/ 	};
/******/
/******/ 	// Object.prototype.hasOwnProperty.call
/******/ 	__webpack_require__.o = function(object, property) { return Object.prototype.hasOwnProperty.call(object, property); };
/******/
/******/ 	// __webpack_public_path__
/******/ 	__webpack_require__.p = "";
/******/
/******/ 	// Load entry module and return exports
/******/ 	return __webpack_require__(__webpack_require__.s = 1);
/******/ })
/************************************************************************/
/******/ ([
/* 0 */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony default export */ __webpack_exports__["a"] = (Object.assign || function (target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = arguments[i];

    for (var key in source) {
      if (Object.prototype.hasOwnProperty.call(source, key)) {
        target[key] = source[key];
      }
    }
  }

  return target;
});

/***/ }),
/* 1 */
/***/ (function(module, exports, __webpack_require__) {

module.exports = __webpack_require__(2);


/***/ }),
/* 2 */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
Object.defineProperty(__webpack_exports__, "__esModule", { value: true });
/* harmony import */ var __WEBPACK_IMPORTED_MODULE_0__createAppData__ = __webpack_require__(3);
/* harmony reexport (binding) */ __webpack_require__.d(__webpack_exports__, "createAppData", function() { return __WEBPACK_IMPORTED_MODULE_0__createAppData__["a"]; });
/* harmony import */ var __WEBPACK_IMPORTED_MODULE_1__createAppTemplate__ = __webpack_require__(7);
/* harmony reexport (binding) */ __webpack_require__.d(__webpack_exports__, "createAppTemplate", function() { return __WEBPACK_IMPORTED_MODULE_1__createAppTemplate__["a"]; });





/***/ }),
/* 3 */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var __WEBPACK_IMPORTED_MODULE_0__convertBindingsToObject__ = __webpack_require__(4);
/* harmony import */ var __WEBPACK_IMPORTED_MODULE_1__convertDataToObject__ = __webpack_require__(6);
/* harmony import */ var __WEBPACK_IMPORTED_MODULE_2__utils_objectAssign__ = __webpack_require__(0);




var createAppData = function createAppData(app) {
  return __WEBPACK_IMPORTED_MODULE_2__utils_objectAssign__["a" /* default */]({}, __WEBPACK_IMPORTED_MODULE_0__convertBindingsToObject__["a" /* default */](app), __WEBPACK_IMPORTED_MODULE_1__convertDataToObject__["a" /* default */](app));
};

/* harmony default export */ __webpack_exports__["a"] = (createAppData);

/***/ }),
/* 4 */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var __WEBPACK_IMPORTED_MODULE_0__utils_arrayFrom__ = __webpack_require__(5);


var convertBindingsToObject = function convertBindingsToObject(app) {
  if (!app.attributes['q-convert-bindings']) {
    return;
  }

  var bindings = app.querySelectorAll('[q-binding]');

  return __WEBPACK_IMPORTED_MODULE_0__utils_arrayFrom__["a" /* default */](bindings).reduce(function (obj, binding) {
    var bindingValue = binding.attributes['q-binding'].value;

    if (bindingValue.indexOf(' as ') > 0) {
      if (bindingValue.indexOf('[') > 0) {
        var _$exec = /(\w+)\[(\d+)\](\.)?(.*)/.exec(bindingValue),
            name = _$exec[1],
            index = _$exec[2],
            dot = _$exec[3],
            prop = _$exec[4];

        obj[name] = obj[name] || [];

        if (dot) {
          obj[name][index] = obj[name][index] || {};

          obj[name][index][prop.split(' as ')[0].trim()] = binding.textContent;
        } else {
          obj[name][index] = binding.textContent;
        }
      } else {
        var _$exec2 = /(\w+)\.(\w+)\s.*/.exec(bindingValue),
            _name = _$exec2[1],
            _prop = _$exec2[2];

        obj[_name] = obj[_name] || {};
        obj[_name][_prop] = binding.textContent;
      }
    } else if (binding.textContent) {
      obj[bindingValue] = binding.textContent;
    }

    return obj;
  }, {});
};

/* harmony default export */ __webpack_exports__["a"] = (convertBindingsToObject);

/***/ }),
/* 5 */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony default export */ __webpack_exports__["a"] = (Array.from || function (object) {
  return [].slice.call(object);
});

/***/ }),
/* 6 */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var __WEBPACK_IMPORTED_MODULE_0__utils_objectAssign__ = __webpack_require__(0);


var convertDataToObject = function convertDataToObject(app) {
  var data = void 0;
  var rData = void 0;

  if (app.attributes['q-data']) {
    data = JSON.parse(app.attributes['q-data'].value);
  }

  if (app.attributes['q-r-data']) {
    rData = JSON.parse(app.attributes['q-r-data'].value);

    Object.keys(rData).forEach(function (key) {
      var keyArray = rData[key].split('.');
      var initKeyValue = window[keyArray[0]];
      var keyValue = initKeyValue && keyArray.length > 1 ?
      // eslint-disable-next-line arrow-body-style
      keyArray.reduce(function (obj, newKey, index) {
        return obj[newKey] || (index === keyArray.length - 1 ? undefined : obj);
      }, initKeyValue) : initKeyValue;

      rData[key] = keyValue;
    });
  }

  return __WEBPACK_IMPORTED_MODULE_0__utils_objectAssign__["a" /* default */]({}, data, rData);
};

/* harmony default export */ __webpack_exports__["a"] = (convertDataToObject);

/***/ }),
/* 7 */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
var createAppTemplate = function createAppTemplate(app) {
  var hadClassName = app.attributes.class;
  var quenchedClassName = (app.className + ' quenched').replace(/\bpre-quench\b/g, '');

  var html = app.outerHTML.replace(/<!--\s*<q>\s*-->[\s\S]*?<!--\s*<\/q>\s*-->/g, '').replace(/ q-binding=".*?\s+as\s+/g, ' q-binding="').replace(/ q-binding="(.*?)"(.*?)>[\s\S]*?<\//g, '$2>{{ $1 }}</');

  if (hadClassName) {
    html = html.replace(/(class=").*?"/, '$1' + quenchedClassName + '"');
  } else {
    html = html.replace(/(<.*?\s)/, '$1class="' + quenchedClassName + '"');
  }

  return html;
};

/* harmony default export */ __webpack_exports__["a"] = (createAppTemplate);

/***/ })
/******/ ]);
});

==> quench-vue-0.5.0.tgz: package/umd/quench-vue.js <==
/*!
 * quench-vue v0.5.0 - http://mattstow.com
 * MIT Licensed
 */
(function webpackUniversalModuleDefinition(root, factory) {
	if(typeof exports === 'object' && typeof module === 'object')
		module.exports = factory();
	else if(typeof define === 'function' && define.amd)
		define([], factory);
	else if(typeof exports === 'object')
		exports["quenchVue"] = factory();
	else
		root["quenchVue"] = factory();
})(this, function() {
return /******/ (function(modules) { // webpackBootstrap
/******/ 	// The module cache
/******/ 	var installedModules = {};
/******/
/******/ 	// The require function
/******/ 	function __webpack_require__(moduleId) {
/******/
/******/ 		// Check if module is in cache
/******/ 		if(installedModules[moduleId]) {
/******/ 			return installedModules[moduleId].exports;
/******/ 		}
/******/ 		// Create a new module (and put it into the cache)
/******/ 		var module = installedModules[moduleId] = {
/******/ 			i: moduleId,
/******/ 			l: false,
/******/ 			exports: {}
/******/ 		};
/******/
/******/ 		// Execute the module function
/******/ 		modules[moduleId].call(module.exports, module, module.exports, __webpack_require__);
/******/
/******/ 		// Flag the module as loaded
/******/ 		module.l = true;
/******/
/******/ 		// Return the exports of the module
/******/ 		return module.exports;
/******/ 	}
/******/
/******/
/******/ 	// expose the modules object (__webpack_modules__)
/******/ 	__webpack_require__.m = modules;
/******/
/******/ 	// expose the module cache
/******/ 	__webpack_require__.c = installedModules;
/******/
/******/ 	// define getter function for harmony exports
/******/ 	__webpack_require__.d = function(exports, name, getter) {
/******/ 		if(!__webpack_require__.o(exports, name)) {
/******/ 			Object.defineProperty(exports, name, {
/******/ 				configurable: false,
/******/ 				enumerable: true,
/******/ 				get: getter
/******/ 			});
/******/ 		}
/******/ 	};
/******/
/******/ 	// getDefaultExport function for compatibility with non-harmony modules
/******/ 	__webpack_require__.n = function(module) {
/******/ 		var getter = module && module.__esModule ?
/******/ 			function getDefault() { return module['default']; } :
/******/ 			function getModuleExports() { return module; };
/******/ 		__webpack_require__.d(getter, 'a', getter);
/******/ 		return getter;
/******/ 	};
/******/
/******/ 	// Object.prototype.hasOwnProperty.call
/******/ 	__webpack_require__.o = function(object, property) { return Object.prototype.hasOwnProperty.call(object, property); };
/******/
/******/ 	// __webpack_public_path__
/******/ 	__webpack_require__.p = "";
/******/
/******/ 	// Load entry module and return exports
/******/ 	return __webpack_require__(__webpack_require__.s = 1);
/******/ })
/************************************************************************/
/******/ ([
/* 0 */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony default export */ __webpack_exports__["a"] = (Object.assign || function (target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = arguments[i];

    for (var key in source) {
      if (Object.prototype.hasOwnProperty.call(source, key)) {
        target[key] = source[key];
      }
    }
  }

  return target;
});

/***/ }),
/* 1 */
/***/ (function(module, exports, __webpack_require__) {

module.exports = __webpack_require__(2);


/***/ }),
/* 2 */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
Object.defineProperty(__webpack_exports__, "__esModule", { value: true });
/* harmony import */ var __WEBPACK_IMPORTED_MODULE_0__createAppData__ = __webpack_require__(3);
/* harmony reexport (binding) */ __webpack_require__.d(__webpack_exports__, "createAppData", function() { return __WEBPACK_IMPORTED_MODULE_0__createAppData__["a"]; });
/* harmony import */ var __WEBPACK_IMPORTED_MODULE_1__createAppTemplate__ = __webpack_require__(7);
/* harmony reexport (binding) */ __webpack_require__.d(__webpack_exports__, "createAppTemplate", function() { return __WEBPACK_IMPORTED_MODULE_1__createAppTemplate__["a"]; });
/* harmony import */ var __WEBPACK_IMPORTED_MODULE_2__createComponentTemplates__ = __webpack_require__(8);
/* harmony reexport (binding) */ __webpack_require__.d(__webpack_exports__, "createComponentTemplates", function() { return __WEBPACK_IMPORTED_MODULE_2__createComponentTemplates__["a"]; });







/***/ }),
/* 3 */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var __WEBPACK_IMPORTED_MODULE_0__convertBindingsToObject__ = __webpack_require__(4);
/* harmony import */ var __WEBPACK_IMPORTED_MODULE_1__convertDataToObject__ = __webpack_require__(6);
/* harmony import */ var __WEBPACK_IMPORTED_MODULE_2__utils_objectAssign__ = __webpack_require__(0);




var createAppData = function createAppData(app) {
  return Object(__WEBPACK_IMPORTED_MODULE_2__utils_objectAssign__["a" /* default */])({}, Object(__WEBPACK_IMPORTED_MODULE_0__convertBindingsToObject__["a" /* default */])(app), Object(__WEBPACK_IMPORTED_MODULE_1__convertDataToObject__["a" /* default */])(app));
};

/* harmony default export */ __webpack_exports__["a"] = (createAppData);

/***/ }),
/* 4 */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var __WEBPACK_IMPORTED_MODULE_0__utils_arrayFrom__ = __webpack_require__(5);


var convertBindingsToObject = function convertBindingsToObject(app) {
  if (!app.attributes['q-convert-bindings']) {
    return;
  }

  var bindings = app.querySelectorAll('[q-binding]');

  return Object(__WEBPACK_IMPORTED_MODULE_0__utils_arrayFrom__["a" /* default */])(bindings).reduce(function (obj, binding) {
    var bindingValue = binding.attributes['q-binding'].value;

    if (bindingValue.indexOf(' as ') > 0) {
      if (bindingValue.indexOf('[') > 0) {
        var _$exec = /(\w+)\[(\d+)\](\.)?(.*)/.exec(bindingValue),
            name = _$exec[1],
            index = _$exec[2],
            dot = _$exec[3],
            prop = _$exec[4];

        obj[name] = obj[name] || [];

        if (dot) {
          obj[name][index] = obj[name][index] || {};

          obj[name][index][prop.split(' as ')[0].trim()] = binding.textContent;
        } else {
          obj[name][index] = binding.textContent;
        }
      } else {
        var _$exec2 = /(\w+)\.(\w+)\s.*/.exec(bindingValue),
            _name = _$exec2[1],
            _prop = _$exec2[2];

        obj[_name] = obj[_name] || {};
        obj[_name][_prop] = binding.textContent;
      }
    } else if (binding.textContent) {
      obj[bindingValue] = binding.textContent;
    }

    return obj;
  }, {});
};

/* harmony default export */ __webpack_exports__["a"] = (convertBindingsToObject);

/***/ }),
/* 5 */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony default export */ __webpack_exports__["a"] = (Array.from || function (object) {
  return [].slice.call(object);
});

/***/ }),
/* 6 */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var __WEBPACK_IMPORTED_MODULE_0__utils_objectAssign__ = __webpack_require__(0);


var convertDataToObject = function convertDataToObject(app) {
  var data = void 0;
  var rData = void 0;

  if (app.attributes['q-data']) {
    data = JSON.parse(app.attributes['q-data'].value);
  }

  if (app.attributes['q-r-data']) {
    rData = JSON.parse(app.attributes['q-r-data'].value);

    Object.keys(rData).forEach(function (key) {
      var keyArray = rData[key].split('.');
      var initKeyValue = window[keyArray[0]];
      var keyValue = initKeyValue && keyArray.length > 1 ?
      // eslint-disable-next-line arrow-body-style
      keyArray.reduce(function (obj, newKey, index) {
        return obj[newKey] || (index === keyArray.length - 1 ? undefined : obj);
      }, initKeyValue) : initKeyValue;

      rData[key] = keyValue;
    });
  }

  return Object(__WEBPACK_IMPORTED_MODULE_0__utils_objectAssign__["a" /* default */])({}, data, rData);
};

/* harmony default export */ __webpack_exports__["a"] = (convertDataToObject);

/***/ }),
/* 7 */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
var createAppTemplate = function createAppTemplate(app) {
  var hadClassName = app.attributes.class;
  var quenchedClassName = (app.className + ' quenched').replace(/\bpre-quench\b/g, '');

  var html = app.outerHTML.replace(/<!--\s*<q>\s*-->[\s\S]*?<!--\s*<\/q>\s*-->/g, '').replace(/\sq-binding=".*?\s+as\s+/g, ' q-binding="').replace(/q-binding="/g, 'v-text="').replace(/(\sv-(text|html).*?>)[\s\S]*?<\//g, '$1</');

  if (hadClassName) {
    html = html.replace(/(class=").*?"/, '$1' + quenchedClassName + '"');
  } else {
    html = html.replace(/(<.*?\s)/, '$1class="' + quenchedClassName + '"');
  }

  return html;
};

/* harmony default export */ __webpack_exports__["a"] = (createAppTemplate);

/***/ }),
/* 8 */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
var createComponentTemplates = function createComponentTemplates(app, components) {
  if (!components) {
    return null;
  }

  Object.keys(components).forEach(function (key) {
    var componentEl = app.querySelector('[q-component="' + key + '"]');

    if (componentEl) {
      var template = '';

      template = componentEl.tagName === 'TEMPLATE' ? componentEl.innerHTML : componentEl.outerHTML;
      template = template.replace(/(\sv-(text|html).*?>)[\s\S]*?<\//g, '$1</').replace(/<!--\s*<q-component>\s*-->[\s\S]*?<!--\s*<\/q-component>\s*-->/g, '').replace(/(?:<!--\s*)?<q-component-partial\s+name=["'](.*?)["']\s*><\/q-component-partial>(\s*-->)?/g, function (match, p1) {
        if (components[key].partials && components[key].partials[p1]) {
          return components[key].partials[p1];
        }

        return '';
      });

      components[key].template = template;
    }
  });

  return components;
};

/* harmony default export */ __webpack_exports__["a"] = (createComponentTemplates);

/***/ })
/******/ ]);
});
